@@ -54,6 +54,7 @@
 #' Zell, A. et al. (1998), 'SNNS Stuttgart Neural Network Simulator User Manual, Version 4.2', IPVR, University of Stuttgart and WSI, University of Tübingen. 
 #' \url{http://www.ra.cs.uni-tuebingen.de/SNNS/}
 #' 
+#' @name SnnsR-class
 #' @seealso \code{\link{$}}, \code{\link{SnnsRObjectFactory}}
 #' @examples
 #' \dontrun{demo(encoderSnnsCLib)} 
@@ -122,19 +123,21 @@ setClass( "SnnsR", representation( variables="environment" ))
 
 #' Enable calling of C++ functions as methods of \code{SnnsR-class} objects.
 #'
-#' This function makes methods of SnnsR__ and SnnsCLib__ accessible via "$".
-#' If no SnnsR__ method is present, then the according SnnsCLib__ 
-#' method is called. This enables a very flexible method handling.
-#' To mask a method from SnnsCLib, e.g. to do some parameter checking or postprocessing,
-#' only a method with the same name, but beginning with SnnsR__ has to be present in R. 
-#' See e.g. \code{\link{SnnsRObject$initializeNet}} for such an implementation. 
+#' This function makes methods of SnnsR__ and SnnsCLib__ accessible via "$". If
+#' no SnnsR__ method is present, then the according SnnsCLib__ method is
+#' called. This enables a very flexible method handling. To mask a method from
+#' SnnsCLib, e.g. to do some parameter checking or postprocessing, only a method
+#' with the same name, but beginning with SnnsR__ has to be present in R.  See
+#' e.g. \code{\link{SnnsRObject$initializeNet}} for such an implementation.
 #' 
-#' Error handling is also done within the method caller. If the result of a function is a list with a member \code{err}, 
-#' then \code{SnnsCLib__error} is called to use the SNNS kernel function to get the corresponding error message code
-#' and an R warning is thrown containing this message.
+#' Error handling is also done within the method caller. If the result of a
+#' function is a list with a member \code{err},  then \code{SnnsCLib__error} is
+#' called to use the SNNS kernel function to get the corresponding error message
+#' code and an R warning is thrown containing this message.
 #' 
-#' Furthermore, a serialization mechanism is implemented which all models present in the package use to be able to
-#' be saved and loaded by R's normal save/load mechanism (as RData files). 
+#' Furthermore, a serialization mechanism is implemented which all models
+#' present in the package use to be able to be saved and loaded by R's normal
+#' save/load mechanism (as RData files).
 #' 
 #' The completely trained object can be serialized with
 #' 
@@ -149,10 +152,11 @@ setClass( "SnnsR", representation( variables="environment" ))
 # @export
 #' @title Method caller for SnnsR objects 
 #' @rdname SnnsRObjectMethodCaller
+#' @name SnnsRObjectMethodCaller
 #' @param x object of class \link{SnnsR-class}
 #' @param name function to call
 #' @usage \S4method{$}{SnnsR}(x, name) 
-#' @aliases $,SnnsR-method
+#' @aliases $,SnnsR-method $
 setMethod( "$", "SnnsR", function(x, name ){
       function(...) {
         #print(x)
@@ -172,14 +176,17 @@ setMethod( "$", "SnnsR", function(x, name ){
             envir = as.environment(-1), 
             ifnotfound = list(FALSE), inherits=TRUE)
         
-        #very usefull for debugging..everytime an SnnsR or SnnsCLib funtion is called, its name is printed
+        #very useful for debugging. Everytime an SnnsR or SnnsCLib function is
+        #called, its name is printed
+        
         #print(name)
         
         if(is.function(myFunc[[1]])) {
           res <- myFunc[[1]](x, ... )
         }
         else {
-          res <- .Call( paste( "SnnsCLib", name, sep = "__" ) , x@variables$snnsCLibPointer , ... )
+          myFuncName <- paste( "SnnsCLib", name, sep = "__" )
+          res <- .Call( myFuncName, x@variables$snnsCLibPointer , ... )
         }
         
         if(is.list(res))
@@ -219,5 +226,3 @@ SnnsRObjectFactory <- function(){
   snnsObject
 }
 
-
-
